@@ -72,7 +72,7 @@ class DrydockServiceClientMeta(type):
 
 
 class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
-    """TradeFlowService provides service to get tradeflow data"""
+    """DryDockService provides service to get dry dock data"""
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
@@ -312,60 +312,6 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
                 client_info=client_info,
             )
 
-    def get_tonnage_dry_dock(self,
-            request: service.GetTonnageDryDockRequest = None,
-            *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
-            metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.GetTonnageDryDockResponse:
-        r"""GetTonnageDryDock retrives timeseries for number of
-        vessels in dry dock at any given time Accepts a segment
-        to return congestion timeseries for. It is possible to
-        return both number of vessels currently in dry dock and
-        the sum of DWT currently in drydock, In addition the api
-        also return the values either in absolute numbers or as
-        percent of global fleet.
-
-        Args:
-            request (oceanbolt.com.drydock_v3.types.GetTonnageDryDockRequest):
-                The request object.  Dry Dock Requests and Responses
-                GetTonnageDryDock
-
-            retry (google.api_core.retry.Retry): Designation of what errors, if any,
-                should be retried.
-            timeout (float): The timeout for this request.
-            metadata (Sequence[Tuple[str, str]]): Strings which should be
-                sent along with the request as metadata.
-
-        Returns:
-            oceanbolt.com.drydock_v3.types.GetTonnageDryDockResponse:
-
-        """
-        # Create or coerce a protobuf request object.
-
-        # Minor optimization to avoid making a copy if the user passes
-        # in a service.GetTonnageDryDockRequest.
-        # There's no risk of modifying the input as we've already verified
-        # there are no flattened fields.
-        if not isinstance(request, service.GetTonnageDryDockRequest):
-            request = service.GetTonnageDryDockRequest(request)
-
-        # Wrap the RPC method; this adds retry and timeout information,
-        # and friendly error handling.
-        rpc = self._transport._wrapped_methods[self._transport.get_tonnage_dry_dock]
-
-        # Send the request.
-        response = rpc(
-            request,
-            retry=retry,
-            timeout=timeout,
-            metadata=metadata,
-        )
-
-        # Done; return the response.
-        return response
-
     def get_dry_dock_stays(self,
             request: service.GetDryDockStaysRequest = None,
             *,
@@ -373,7 +319,7 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetDryDockStaysResponse:
-        r"""ListDryDockStays retrives individual completed dry
+        r"""GetDryDockStays retrives individual completed dry
         dock stays
 
         Args:
@@ -414,6 +360,150 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
         # Done; return the response.
         return response
 
+    def get_dry_dock_timeseries(self,
+            request: service.GetDryDockRequest = None,
+            *,
+            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.DryDockResponse:
+        r"""GetDryDockTimeseries retrieves dry dock data for a specified
+        list of port_ids/segments
+
+        Args:
+            request (oceanbolt.com.drydock_v3.types.GetDryDockRequest):
+                The request object. DryDock request object.
+
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.drydock_v3.types.DryDockResponse:
+                DryDock responseobject.
+        """
+        # Create or coerce a protobuf request object.
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a service.GetDryDockRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, service.GetDryDockRequest):
+            request = service.GetDryDockRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.get_dry_dock_timeseries]
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def get_dry_dock_web(self,
+            request: service.GetDryDockRequest = None,
+            *,
+            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.DryDockResponse:
+        r"""GetDryDockWeb retrieves dry dock data for a specified list of
+        port_ids/segments
+
+        Args:
+            request (oceanbolt.com.drydock_v3.types.GetDryDockRequest):
+                The request object. DryDock request object.
+
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.drydock_v3.types.DryDockResponse:
+                DryDock responseobject.
+        """
+        # Create or coerce a protobuf request object.
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a service.GetDryDockRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, service.GetDryDockRequest):
+            request = service.GetDryDockRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.get_dry_dock_web]
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def get_dry_dock_vessels(self,
+            request: service.GetDryDockRequest = None,
+            *,
+            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.DryDockResponse:
+        r"""GetDryDockVessels retrieves dry dock data for a specified list
+        of port_ids/segments
+
+        Args:
+            request (oceanbolt.com.drydock_v3.types.GetDryDockRequest):
+                The request object. DryDock request object.
+
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.drydock_v3.types.DryDockResponse:
+                DryDock responseobject.
+        """
+        # Create or coerce a protobuf request object.
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a service.GetDryDockRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, service.GetDryDockRequest):
+            request = service.GetDryDockRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.get_dry_dock_vessels]
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
 
 
 
