@@ -1,5 +1,5 @@
 from oceanbolt.sdk.client import APIClient
-from oceanbolt.sdk.helpers import (pb_list_to_pandas)
+from oceanbolt.sdk.helpers import (pb_list_to_pandas,wrapPoints)
 
 
 class DistanceCalculator:
@@ -19,15 +19,19 @@ class DistanceCalculator:
         self.client = client._distance_client()
 
     def shortest_route(self, **kwargs):
-        return pb_list_to_pandas(self.client.calculate_distance(kwargs).total_shortest_path)
+        kwargs = wrapPoints(kwargs)
+        return pb_list_to_pandas(self.client.calculate_distance(request=kwargs, metadata=(('x-ob-platform', 'bulk'),)).total_shortest_path)
 
     def distance(self, **kwargs):
+        kwargs = wrapPoints(kwargs)
         return self.client.calculate_distance(kwargs).total_distance
 
     def duration(self, **kwargs):
+        kwargs = wrapPoints(kwargs)
         if kwargs.get("speed") <= 0:
             raise ValueError("Speed cannot be negative in duration call.")
         return self.client.calculate_distance(kwargs).total_duration_hours
 
     def get_raw(self, **kwargs):
+        kwargs = wrapPoints(kwargs)
         return self.client.calculate_distance(kwargs)
